/*:
 
 # Directionality
 ### A playground for testing directional localization APIs.
 
 This playground has a few samples of the localization tools provided by Foundation and UIKit on iOS.
 
 */

import UIKit
import PlaygroundSupport

/*: 
 
 ## Locales
 NSLocale provides several methods for checking a locale's directionality, including left to right and top to bottom. Every locale in Xcode 8's playground reports a line direction of top to bottom. Here we log out every language code and its direction informatoin.
 */

print(header(with: "1 & 2. NSLocale"))

print(localeInformation(for: "en")) // English
print(localeInformation(for: "fr")) // French
print(localeInformation(for: "ar")) // Arabic
print(localeInformation(for: "he")) // Hebrew
print(localeInformation(for: "ja")) // Japanese

/*:
 ## UIApplication Layout
 UIApplication defines the general layout of the application, based on system preferences.
 
 ➡️ for English, ⬅️ for Arabic and Hebrew. Try changing your system layout on your Mac and running this again.
 */


print(header(with: "3. UIApplication"))


let direction = UIApplication.shared.userInterfaceLayoutDirection.description

print("UIApplication.shared.userInterfaceLayoutDirection: \(direction)")

/*:
 ## NSParagraphStyle and NSMutableParagraphStyle
 */

print(header(with: "4 & 5. NSMutableParagraphStyle"))
let defaultParagraphStyle = NSParagraphStyle()
let defaultDirection = defaultParagraphStyle.baseWritingDirection.description

print("Default direction: \(defaultDirection)")

let englishString = "Hello World!"
let hebrewString = "שלום עולם!"
let mixedString = "Hello World! translates to שלום עולם!"

let mutableParagraphStyle = NSMutableParagraphStyle()
mutableParagraphStyle.baseWritingDirection = .rightToLeft

print("Mutable direction: \(mutableParagraphStyle.baseWritingDirection.description)")

let attributes = [
    NSParagraphStyleAttributeName: mutableParagraphStyle,
    NSForegroundColorAttributeName: UIColor.blue
]

let attributedString = NSAttributedString(string: englishString, attributes: attributes)

let label = UILabel(frame: .zero)
label.attributedText = attributedString

// MARK: - Displaying the RTL text

let iPhoneSE = DeviceConfiguration(name: "iPhone SE", width: 320, height: 480, density: 2.0)
let window = PlaygroundWindow(configuration: iPhoneSE)
let viewController = UIViewController()
window.rootViewController = viewController


viewController.view.bounds = iPhoneSE.bounds
viewController.view.translatesAutoresizingMaskIntoConstraints = false
viewController.view.addSubview(label)
label.translatesAutoresizingMaskIntoConstraints = false
label.leadingAnchor.constraint(equalTo: viewController.view.leadingAnchor)
label.trailingAnchor.constraint(equalTo: viewController.view.trailingAnchor)
label.topAnchor.constraint(equalTo: viewController.topLayoutGuide.bottomAnchor)
label.setContentHuggingPriority(UILayoutPriorityRequired, for: .vertical)
label.setContentCompressionResistancePriority(UILayoutPriorityRequired, for: .vertical)

PlaygroundPage.current.liveView = viewController.view
