import Foundation

// We use this to format outputs.
let currentLocale = NSLocale(localeIdentifier: NSLocale.autoupdatingCurrent.identifier)

// MARK: - Helper Functions

/// Returns direction information about a given language code.
///
/// - Parameter languageCode: The language code to look up.
/// - Returns: A string containing line and character directions for the locale.
public func localeInformation(for languageCode: String) -> String
{
    // Using a language code as a localeIdentifier might not be the best idea...
    let locale = NSLocale(localeIdentifier: languageCode)
    
    // This is where we pass in a language code
    let characterDirection = NSLocale.characterDirection(forLanguage: languageCode)
    let lineDirection = NSLocale.lineDirection(forLanguage: languageCode)
    
    let localeName = displayName(for: locale)
    
    return "\(localeName) (\(locale.languageCode)) lineDirection: \(lineDirection.description) characterDirection: \(characterDirection.description)"
}


/// Returns a display name for a given locale.
///
/// - Parameter locale: The locale
/// - Returns: The name of the locale. If the current locale and the passed in locale are not the same, the display name contains both.
public func displayName(for locale:NSLocale) -> String
{
    let nameInCurrentLocale = displayName(for: locale.languageCode, with: currentLocale)
    let localeNameInThatLocale = displayName(for: locale.languageCode, with: locale)
    
    if nameInCurrentLocale == localeNameInThatLocale
    {
        return nameInCurrentLocale
    }
    
    return "\(nameInCurrentLocale) / \(localeNameInThatLocale)"
}

/// Converts a language code into the language name, given a locale to use for display.
///
/// - Parameters:
///   - languageCode: The language code to convert.
///   - displayLocale: The locale to format the display.
/// - Returns: A user-presentable version of the language name if NSLocale can provide it, otherwise the original language code.
public func displayName(for languageCode: String, with displayLocale: NSLocale) -> String
{
    return displayLocale.displayName(forKey: NSLocale.Key.languageCode, value: languageCode) ?? languageCode
}


